========== Claun help ========== User entity ================== :Author: Jiri Chadima :Version: 2012/04/18 Description ----------- Users identify, who interacts with the system. Information about them is stored in **couchDB** as a JSON document. By using the administration form, you can let the server create the document for you. A full example user document can be seen in the user.json_ file. Every user has its own document. Some fields in the document are generated by the server. They are described in the appropriate module. Form fields ---------------- The fields in the **user** form are: - **Name** - User's name. It can contain any characters. (mandatory) - **Password** - User's initial password. He can change it after he logs in. You are able to change someone's password again (Not recommended). - **Permissions** - List of groups the user belongs to. Every user should have be in the *all* group. - **Allowed** - If the user can log in. If false, he is not allowed to do so. .. _user.json: user.json